@@ -1,6 +1,6 @@
 /*--------------------------------------------------------------------------
- * LuaSec 0.4
- * Copyright (C) 2006-2009 Bruno Silvestre
+ * LuaSec 0.4.1
+ * Copyright (C) 2006-2011 Bruno Silvestre
  *
  *--------------------------------------------------------------------------*/
 
@@ -220,6 +220,9 @@ static int meth_create(lua_State *L)
   SSL_set_fd(ssl->ssl, (int) SOCKET_INVALID);
   SSL_set_mode(ssl->ssl, SSL_MODE_ENABLE_PARTIAL_WRITE | 
     SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER);
+#if defined(SSL_MODE_RELEASE_BUFFERS)
+  SSL_set_mode(ssl->ssl, SSL_MODE_RELEASE_BUFFERS);
+#endif
   if (mode == MD_CTX_SERVER)
     SSL_set_accept_state(ssl->ssl);
   else
